@@ -8,27 +8,33 @@ use strict;
 
 Oak::Filer::Component - Filer to save/load data into/from Components
 
-=head1 SYNOPSIS
-
-  require Oak::Filer::Component;
-
-  my $filer = new Oak::Filer::Component(
-					FILENAME => "tralala.xml", # mandatory, any supported by DBI
-				       )
-
-  my $hr_props = $filer->load("mine");
-  my $hr_owned = $filer->load("owned");
-  $filer->store(
-		mine => $hr_props,
-		owned => $hr_owned
-	       );
-
 =head1 DESCRIPTION
 
 This module provides access for saving and reading data into a Component XML, to be used by
 components. Must pass XML FILENAME
 
-=cut
+=head1 HIERARCHY
+
+L<Oak::Object|Oak::Object>
+
+L<Oak::Filer|Oak::Filer>
+
+L<Oak::Filer::Component|Oak::Filer::Component>
+
+
+=head1 PROPERTIES
+
+=over
+
+=item FILENAME
+
+The name of the XML file. Defined by constructor
+
+=back
+
+=head1 METHODS
+
+=over
 
 =item constructor
 
@@ -48,7 +54,7 @@ sub constructor{
 }
 
 
-=cut
+=over
 
 =item load
 
@@ -81,7 +87,7 @@ sub load {
 	return $self->{__OWNED__} if $what eq 'owned';
 }
 
-=cut
+=over
 
 =item store
 
@@ -100,7 +106,6 @@ when trying to read the XML file.
 
 sub store {
 	my $self = shift;
-	$self->load;
 	my %parms = @_;
 	$self->{__MINE__} = $parms{mine} if ref $parms{mine} eq "HASH";
 	$self->{__OWNED__} = $parms{owned} if ref $parms{owned} eq "HASH";
@@ -108,7 +113,7 @@ sub store {
 	require XML::Writer;
 	my ($output, $writer);
 	$output = new IO::File(">".$self->get('FILENAME')) || throw Oak::Filer::Component::Error::ErrorWritingXML;
-	$writer = new XML::Writer(OUTPUT => $output) || throw Oak::Filer::Component::Error::ErrorWritingXML;
+	$writer = new XML::Writer(OUTPUT => $output, DATA_MODE => 1, DATA_INDENT => 4) || throw Oak::Filer::Component::Error::ErrorWritingXML;
 	$writer->startTag('main');
 	for (keys %{$self->{__MINE__}}) {
 		$writer->startTag('prop', 'name' => $_, 'value' => $self->{__MINE__}{$_});
@@ -133,9 +138,11 @@ sub store {
 #################################################################
 package Oak::Filer::Component::XMLHandlers;
 
-$Oak::Filer::Component::XMLHandlers::OWNEDNAME = '';
-%Oak::Filer::Component::XMLHandlers::OWNED = ();
-%Oak::Filer::Component::XMLHandlers::MINE = ();
+sub Init {
+	$Oak::Filer::Component::XMLHandlers::OWNEDNAME = '';
+	%Oak::Filer::Component::XMLHandlers::OWNED = ();
+	%Oak::Filer::Component::XMLHandlers::MINE = ();
+}
 
 sub Start {
         my $p = shift;
@@ -191,6 +198,8 @@ sub stringify {
 	return "Missing XML File";
 }
 
+=over
+
 =item Oak::Filer::Component::Error::ErrorReadingXML
 
 This error is throwed when there is some problem with the XML while trying to read it.
@@ -206,6 +215,8 @@ sub stringify {
 	return "There was something wrong when trying to read the XML file";
 }
 
+=over
+
 =item Oak::Filer::Component::Error::ErrorWritingXML
 
 This error is throwed when there is some problem with the XML while trying to read it.
@@ -221,6 +232,32 @@ sub stringify {
 	return "There was something wrong when trying to write the XML file";
 }
 
-
-
 1;
+
+__END__
+
+=head1 EXAMPLES
+
+  require Oak::Filer::Component;
+
+  my $filer = new Oak::Filer::Component(
+					FILENAME => "tralala.xml"
+				       )
+
+  my $hr_props = $filer->load("mine");
+  my $hr_owned = $filer->load("owned");
+  $filer->store(
+		mine => $hr_props,
+		owned => $hr_owned
+	       );
+
+
+=head1 COPYRIGHT
+
+Copyright (c) 2001
+Daniel Ruoso <daniel@ruoso.com>
+All rights reserved.
+This program is free software; you can redistribute it and/or
+modify it under the same terms as Perl itself.
+
+
