@@ -2,7 +2,6 @@ package Oak::Filer::DBI;
 
 use base qw(Oak::Filer);
 use Error qw(:try);
-use DBI;
 
 use strict;
 
@@ -10,40 +9,44 @@ use strict;
 
 Oak::Filer::DBI - Filer to save/load data into/from DBI tables
 
-=head1 SYNOPSIS
-
-  require Oak::Filer::DBI;
-
-  my $filer = new Oak::Filer::DBI
-   (
-    io => $iodbiobj,		# mandatory, an Oak::IO::DBI object.
-    table => "tablename",	# mandatory to enable load and store.
-				#   table to work in selects and updates
-    where => {primary => value},# this is optional, once itsn't passed 
-				# you assumes that u're creating a new object
-   )
-    
-  my $nome = $filer->load("nome");
-  $filer->store(nome => lc($nome));
-
 =head1 DESCRIPTION
 
 This module provides access for saving data into a DBI table, to be used by
 a Persistent descendant to save its data. Must pass table, and where
 
-=head1 OBJECT METHODS
+=head1 HIERARCHY
 
-=over 4
+L<Oak::Object|Oak::Object>
 
-=item constructor(PARAMS)
+L<Oak::Filer|Oak::Filer>
 
-Called by new. You do not want do call it by yourself.
-Prepare to work with determined table and register (setted by privalue).
+L<Oak::Filer::DBI|Oak::Filer::DBI>
 
-Could raise the Oak::Error::ParamsMissing exception.
+
+=head1 PROPERTIES
+
+=over
+
+=item io
+
+Mandatory property. Defines the Oak::IO::DBI object that will be used
+to communicate with the database. This property contains a reference to
+the Oak::IO::DBI object, not the name.
+
+=item table
+
+Mandatory property. Defines the table that this filer will work on.
+
+=item where
+
+Optional. Contains a hashref with the following format
+  {primarykey => value}
+This will be used to create the custom SQL when fetching data.
 
 =back
 
+=head1 METHODS
+
 =cut
 
 sub constructor {
@@ -66,7 +69,7 @@ sub constructor {
 Loads one or more properties of the selected DBI table with the selected WHERE statement.
 Returns a hash with the properties.
 
-see do_sql for possible exceptions.
+see Oak::IO::DBI::do_sql for possible exceptions.
 
 =back
 
@@ -91,7 +94,7 @@ sub load {
 
 Saves the data into the selected table with the selected WHERE statement.
 
-see do_sql for possible exceptions.
+see Oak::IO::DBI::do_sql for possible exceptions.
 
 =back
 
@@ -114,6 +117,18 @@ sub store {
         return 1;
 }
 
+=over
+
+=item insert(FIELD=>VALUE,FIELD=>VALUE,...)
+
+Insert a register in the selected table with the data
+in the parameters
+
+see Oak::IO::DBI::do_sql for possible exceptions.
+
+=back
+
+=cut
 
 sub insert {
 	my $self = shift;
@@ -134,6 +149,28 @@ sub insert {
 	return $sth;
 }
 
+=over
+
+=item delete
+
+Delete the entry from the table
+
+see Oak::IO::DBI::do_sql for possible exceptions.
+
+=back
+
+=cut
+
+sub delete {
+        my $self = shift;
+        my $table = $self->get('table');
+        my $where = $self->make_where_statement;
+        return 0 unless $table && $where;
+        my $sql = "DELETE FROM $table WHERE $where";
+        $self->get('io')->do_sql($sql);
+        return 1;
+}
+
 #internal function
 sub make_where_statement {
 	my $self = shift;
@@ -151,9 +188,21 @@ sub make_where_statement {
 
 __END__
 
-=head1 BUGS
+=head1 EXAMPLES
 
-Too early to know...
+  require Oak::Filer::DBI;
+
+  my $filer = new Oak::Filer::DBI
+   (
+    io => $iodbiobj,		# mandatory, an Oak::IO::DBI object.
+    table => "tablename",	# mandatory to enable load and store.
+				#   table to work in selects and updates
+    where => {primary => value},# this is optional, once itsn't passed 
+				# you assumes that u're creating a new object
+   )
+    
+  my $nome = $filer->load("nome");
+  $filer->store(nome => lc($nome));
 
 =head1 COPYRIGHT
 
@@ -161,4 +210,3 @@ Copyright (c) 2001 Daniel Ruoso <daniel@ruoso.com> and Rodolfo Sikora <rodolfo@t
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
 
-=cut
